@@ -1,10 +1,7 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 from collections import OrderedDict
 
-from openpyxl.compat import basestring
-
 from openpyxl.descriptors import (
     Typed,
     Integer,
@@ -13,10 +10,8 @@ from openpyxl.descriptors import (
     Bool,
     Set,
 )
-from openpyxl.descriptors.nested import Nested
-from openpyxl.descriptors.sequence import NestedSequence, ValueSequence
+from openpyxl.descriptors.sequence import ValueSequence
 from openpyxl.descriptors.serialisable import Serialisable
-from openpyxl.xml.constants import PACKAGE_CHARTS
 
 from ._3d import _3DBase
 from .data_source import AxDataSource, NumRef
@@ -51,7 +46,7 @@ class ChartBase(Serialisable):
     layout = Typed(expected_type=Layout, allow_none=True)
     roundedCorners = Bool(allow_none=True)
     axId = ValueSequence(expected_type=int)
-    visible_cells_only = Bool()
+    visible_cells_only = Bool(allow_none=True)
     display_blanks = Set(values=['span', 'gap', 'zero'])
 
     _series_type = ""
@@ -81,6 +76,11 @@ class ChartBase(Serialisable):
         self.plot_area = PlotArea()
         self.axId = axId
         self.display_blanks = 'gap'
+        self.pivotSource = None
+        self.pivotFormats = ()
+        self.visible_cells_only = True
+        self.idx_base = 0
+        super(ChartBase, self).__init__()
 
 
     def __hash__(self):
@@ -111,7 +111,7 @@ class ChartBase(Serialisable):
         from .chartspace import ChartSpace, ChartContainer
         self.plot_area.layout = self.layout
 
-        idx_base = 0
+        idx_base = self.idx_base
         for chart in self._charts:
             if chart not in self.plot_area._charts:
                 chart.idx_base = idx_base
@@ -126,9 +126,11 @@ class ChartBase(Serialisable):
             container.backWall = chart.backWall
         container.plotVisOnly = self.visible_cells_only
         container.dispBlanksAs = self.display_blanks
+        container.pivotFmts = self.pivotFormats
         cs = ChartSpace(chart=container)
         cs.style = self.style
         cs.roundedCorners = self.roundedCorners
+        cs.pivotSource = self.pivotSource
         return cs.to_tree()
 
 
@@ -164,10 +166,9 @@ class ChartBase(Serialisable):
         else:
             values = data.cols
 
-        for v in values:
-            range_string = u"{0}!{1}:{2}".format(data.sheetname, v[0], v[-1])
-            series = SeriesFactory(range_string, title_from_data=titles_from_data)
-            self.ser.append(series)
+        for ref in values:
+            series = SeriesFactory(ref, title_from_data=titles_from_data)
+            self.series.append(series)
 
 
     def append(self, value):
