@@ -1,15 +1,10 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
-    Typed,
-    String,
-    Integer,
-    Bool,
-    Set,
-    Float,
     Sequence,
-    Alias
+    Alias,
+    Typed
 )
 from openpyxl.descriptors.excel import ExtensionList
 from openpyxl.descriptors.nested import (
