@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -9,7 +8,8 @@ from openpyxl.descriptors import (
     Bool,
     Integer,
     NoneSet,
-    Float,)
+    Float,
+)
 
 
 from .colors import ColorChoice
@@ -17,12 +17,14 @@ from .colors import ColorChoice
 
 class TintEffect(Serialisable):
 
+    tagname = "tint"
+
     hue = Integer()
     amt = Integer()
 
     def __init__(self,
-                 hue=None,
-                 amt=None,
+                 hue=0,
+                 amt=0,
                 ):
         self.hue = hue
         self.amt = amt
@@ -30,12 +32,14 @@ class TintEffect(Serialisable):
 
 class LuminanceEffect(Serialisable):
 
-    bright = Integer()
-    contrast = Integer()
+    tagname = "lum"
+
+    bright = Integer() #Pct ?
+    contrast = Integer() #Pct#
 
     def __init__(self,
-                 bright=None,
-                 contrast=None,
+                 bright=0,
+                 contrast=0,
                 ):
         self.bright = bright
         self.contrast = contrast
@@ -59,7 +63,8 @@ class HSLEffect(Serialisable):
 
 class GrayscaleEffect(Serialisable):
 
-    pass
+    tagname = "grayscl"
+
 
 class FillOverlayEffect(Serialisable):
 
