@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -552,7 +552,7 @@ class PageField(Serialisable):
 
     fld = Integer()
     item = Integer(allow_none=True)
-    hier = Integer()
+    hier = Integer(allow_none=True)
     name = String(allow_none=True)
     cap = String(allow_none=True)
     extLst = Typed(expected_type=ExtensionList, allow_none=True)
