@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 import re
 
@@ -41,17 +40,18 @@ BUILTIN_FORMATS = {
     39: '#,##0.00_);(#,##0.00)',
     40: '#,##0.00_);[Red](#,##0.00)',
 
-    41: '_(* #,##0_);_(* \(#,##0\);_(* "-"_);_(@_)',
-    42: '_("$"* #,##0_);_("$"* \(#,##0\);_("$"* "-"_);_(@_)',
-    43: '_(* #,##0.00_);_(* \(#,##0.00\);_(* "-"??_);_(@_)',
+    41: r'_(* #,##0_);_(* \(#,##0\);_(* "-"_);_(@_)',
+    42: r'_("$"* #,##0_);_("$"* \(#,##0\);_("$"* "-"_);_(@_)',
+    43: r'_(* #,##0.00_);_(* \(#,##0.00\);_(* "-"??_);_(@_)',
 
-    44: '_("$"* #,##0.00_)_("$"* \(#,##0.00\)_("$"* "-"??_)_(@_)',
+    44: r'_("$"* #,##0.00_)_("$"* \(#,##0.00\)_("$"* "-"??_)_(@_)',
     45: 'mm:ss',
     46: '[h]:mm:ss',
     47: 'mmss.0',
     48: '##0.0E+0',
     49: '@', }
 
+BUILTIN_FORMATS_MAX_SIZE = 164
 BUILTIN_FORMATS_REVERSE = dict(
         [(value, key) for key, value in BUILTIN_FORMATS.items()])
 
@@ -135,7 +135,11 @@ def is_builtin(fmt):
 
 def builtin_format_code(index):
     """Return one of the standard format codes by index."""
-    return BUILTIN_FORMATS[index]
+    try:
+        fmt = BUILTIN_FORMATS[index]
+    except KeyError:
+        fmt = None
+    return fmt
 
 
 def builtin_format_id(fmt):
