@@ -1,13 +1,14 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """Reader for a single worksheet."""
+import traceback
 from warnings import warn
 
 # compatibility imports
 from openpyxl.xml.functions import iterparse
 
 # package imports
-from openpyxl.cell import Cell
+from openpyxl.cell import Cell, MergedCell
 from openpyxl.cell.text import Text
 from openpyxl.worksheet.dimensions import (
     ColumnDimension,
@@ -85,14 +86,14 @@ class WorkSheetParser(object):
 
     def __init__(self, src, shared_strings, data_only=False,
                  epoch=WINDOWS_EPOCH, date_formats=set()):
-        self.min_row = self.min_col = self.max_row = self.max_column = None
+        self.min_row = self.min_col = None
         self.epoch = epoch
         self.source = src
         self.shared_strings = shared_strings
         self.data_only = data_only
         self.shared_formulae = {}
         self.array_formulae = {}
-        self.max_row = self.max_column = 0
+        self.row_counter = self.col_counter = 0
         self.tables = TablePartList()
         self.date_formats = date_formats
         self.row_dimensions = {}
@@ -103,7 +104,8 @@ class WorkSheetParser(object):
         self.formatting = []
         self.legacy_drawing = None
         self.merged_cells = None
-        self.page_breaks = []
+        self.row_breaks = RowBreak()
+        self.col_breaks = ColBreak()
 
 
     def parse(self):
@@ -132,6 +134,7 @@ class WorkSheetParser(object):
             TABLE_TAG: ('tables', TablePartList),
             HYPERLINK_TAG: ('hyperlinks', HyperlinkList),
             MERGE_TAG: ('merged_cells', MergeCells),
+
         }
 
         it = iterparse(self.source)
@@ -172,7 +175,7 @@ class WorkSheetParser(object):
     def parse_cell(self, element):
         data_type = element.get('t', 'n')
         coordinate = element.get('r')
-        self.max_column += 1
+        self.col_counter += 1
         style_id = element.get('s', 0)
         if style_id:
             style_id = int(style_id)
@@ -185,7 +188,7 @@ class WorkSheetParser(object):
         if coordinate:
             row, column = coordinate_to_tuple(coordinate)
         else:
-            row, column = self.max_row, self.max_column
+            row, column = self.row_counter, self.col_counter
 
         if not self.data_only and element.find(FORMULA_TAG) is not None:
             data_type = 'f'
@@ -258,22 +261,27 @@ class WorkSheetParser(object):
         attrs = dict(row.attrib)
 
         if "r" in attrs:
-            self.max_row = int(attrs['r'])
+            self.row_counter = int(attrs['r'])
         else:
-            self.max_row += 1
+            self.row_counter += 1
+        self.col_counter = 0
 
         keys = {k for k in attrs if not k.startswith('{')}
-        if keys != {'r', 'spans'} and keys != {'r'}:
+        if keys - {'r', 'spans'}:
             # don't create dimension objects unless they have relevant information
-            self.row_dimensions[attrs['r']] = attrs
+            self.row_dimensions[str(self.row_counter)] = attrs
 
         cells = [self.parse_cell(el) for el in row]
-        return self.max_row, cells
+        return self.row_counter, cells
 
 
     def parse_formatting(self, element):
-        cf = ConditionalFormatting.from_tree(element)
-        self.formatting.append(cf)
+        try:
+            cf = ConditionalFormatting.from_tree(element)
+            self.formatting.append(cf)
+        except TypeError:
+            msg = f"Failed to load a conditional formatting rule. It will be discarded. Cause: {traceback.format_exc()}"
+            warn(msg)
 
 
     def parse_sheet_protection(self, element):
@@ -299,17 +307,19 @@ class WorkSheetParser(object):
 
     def parse_row_breaks(self, element):
         brk = RowBreak.from_tree(element)
-        self.page_breaks.append(brk)
+        self.row_breaks = brk
 
 
     def parse_col_breaks(self, element):
         brk = ColBreak.from_tree(element)
-        self.page_breaks.append(brk)
+        self.col_breaks = brk
 
 
     def parse_custom_views(self, element):
-        # clear page_breaks to avoid duplication
-        self.page_breaks = []
+        # clear page_breaks to avoid duplication which Excel doesn't like
+        # basically they're ignored in custom views
+        self.row_breaks = RowBreak()
+        self.col_breaks = ColBreak()
 
 
 class WorksheetReader(object):
@@ -332,7 +342,8 @@ class WorksheetReader(object):
                 c.data_type = cell['data_type']
                 self.ws._cells[(cell['row'], cell['column'])] = c
         self.ws.formula_attributes = self.parser.array_formulae
-        self.ws._current_row = self.parser.max_row
+        if self.ws._cells:
+            self.ws._current_row = self.ws.max_row # use cells not row dimensions
 
 
     def bind_formatting(self):
@@ -350,11 +361,17 @@ class WorksheetReader(object):
 
 
     def bind_merged_cells(self):
+        from openpyxl.worksheet.cell_range import MultiCellRange
+        from openpyxl.worksheet.merge import MergedCellRange
         if not self.parser.merged_cells:
             return
 
+        ranges = []
         for cr in self.parser.merged_cells.mergeCell:
-            self.ws.merge_cells(cr.ref)
+            mcr = MergedCellRange(self.ws, cr.ref)
+            self.ws._clean_merge_range(mcr)
+            ranges.append(mcr)
+        self.ws.merged_cells = MultiCellRange(ranges)
 
 
     def bind_hyperlinks(self):
@@ -371,8 +388,19 @@ class WorksheetReader(object):
                         except AttributeError:
                             pass
             else:
-                self.ws[link.ref].hyperlink = link
+                cell = self.ws[link.ref]
+                if isinstance(cell, MergedCell):
+                    cell = self.normalize_merged_cell_link(cell.coordinate)
+                cell.hyperlink = link
 
+    def normalize_merged_cell_link(self, coord):
+        """
+        Returns the appropriate cell to which a hyperlink, which references a merged cell at the specified coordinates,
+        should be bound.
+        """
+        for rng in self.ws.merged_cells:
+            if coord in rng:
+                return self.ws.cell(*rng.top[0])
 
     def bind_col_dimensions(self):
         for col, cd in self.parser.column_dimensions.items():
@@ -394,7 +422,9 @@ class WorksheetReader(object):
         for k in ('print_options', 'page_margins', 'page_setup',
                   'HeaderFooter', 'auto_filter', 'data_validations',
                   'sheet_properties', 'views', 'sheet_format',
-                  'page_breaks', 'scenarios', 'legacy_drawing'):
+                  'row_breaks', 'col_breaks', 'scenarios', 'legacy_drawing',
+                  'protection',
+                  ):
             v = getattr(self.parser, k, None)
             if v is not None:
                 setattr(self.ws, k, v)
