@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 import atexit
 from collections import defaultdict
@@ -234,7 +234,7 @@ class WorksheetWriter:
 
 
     def write_breaks(self):
-        brks = self.ws.page_breaks
+        brks = (self.ws.row_breaks, self.ws.col_breaks)
         for brk in brks:
             if brk:
                 self.xf.send(brk.to_tree())
@@ -262,15 +262,18 @@ class WorksheetWriter:
     def write_tables(self):
         tables = TablePartList()
 
-        for table in self.ws._tables:
+        for table in self.ws._tables.values():
             if not table.tableColumns:
                 table._initialise_columns()
                 if table.headerRowCount:
-                    row = self.ws[table.ref][0]
-                    for cell, col in zip(row, table.tableColumns):
-                        if cell.data_type != "s":
-                            warn("File may not be readable: column headings must be strings.")
-                        col.name = str(cell.value)
+                    try:
+                        row = self.ws[table.ref][0]
+                        for cell, col in zip(row, table.tableColumns):
+                            if cell.data_type != "s":
+                                warn("File may not be readable: column headings must be strings.")
+                            col.name = str(cell.value)
+                    except TypeError:
+                        warn("Column headings are missing, file may not be readable")
             rel = Relationship(Type=table._rel_type, Target="")
             self._rels.append(rel)
             table._rel_id = rel.Id
