@@ -1,6 +1,3 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2019 openpyxl
-
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
     String,
@@ -51,7 +48,6 @@ class HyperlinkList(Serialisable):
     def __bool__(self):
         return bool(self.hyperlink)
 
-    __nonzero__ = __bool__
 
 
     def __len__(self):
