@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -84,7 +83,6 @@ class PrintPageSetup(Serialisable):
         return bool(dict(self))
 
 
-    __nonzero__ = __bool__
 
 
     @property
@@ -149,7 +147,6 @@ class PrintOptions(Serialisable):
         return bool(dict(self))
 
 
-    __nonzero__ = __bool__
 
 
 class PageMargins(Serialisable):
